@@ -6,9 +6,11 @@ function rz = vecrotz(angle)
 % 
 %   rz = vecrotz(angle);
 % 
-% Parameters:
+% INPUT:
 % 
 %   angle	: rotation angle defined in radians
+%
+% OUTPUT:
 % 
 %   rz		: (4x4) Transformation matrix.
 % 
@@ -34,13 +36,27 @@ function rz = vecrotz(angle)
 %    trans = vecrotz(%pi/4);
 %    rline = nrbtform(line, trans);
 % 
-% See:
+% See also:
 % 
 %    nrbtform
+%
+%    Copyright (C) 2000 Mark Spink
+%
+%    This program is free software: you can redistribute it and/or modify
+%    it under the terms of the GNU General Public License as published by
+%    the Free Software Foundation, either version 2 of the License, or
+%    (at your option) any later version.
 
-%  Dr D.M. Spink
-%  Copyright (c) 2000.
+%    This program is distributed in the hope that it will be useful,
+%    but WITHOUT ANY WARRANTY; without even the implied warranty of
+%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+%    GNU General Public License for more details.
+%
+%    You should have received a copy of the GNU General Public License
+%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 sn = sin(angle);
 cn = cos(angle);
 rz = [cn -sn 0 0; sn cn 0 0; 0 0 1 0; 0 0 0 1];
+
+end
